# Decoupled Blocks Powered by Paragraphs

## **Introduction**
The **Decoupled Blocks Powered by Paragraphs** module provides a flexible solution for exposing blocks from the active Drupal theme. These blocks are enhanced with injected paragraph entities, making them ready for seamless consumption by decoupled frontend frameworks like React and Next.js.

This module is ideal for developers seeking to dynamically fetch and render structured block content for headless applications.

---

## **Features**
- **Exposes Theme Blocks:** Retrieve and display blocks injected with paragraph entities.
- **API-Driven:** Access the blocks via a simple API endpoint.
  ```
  /api/decoupled/_blocks?path=/given-path
  ```
- **Customizable Data Exposure:** Control which paragraph fields are exposed by leveraging the provided hook.
- **Headless Ready:** Optimized for modern decoupled frontends.

---

## **Post-Installation**
### **Configuration Steps:**
1. Enable the module using the Admin UI or Drush:
   ```bash
   drush en decoupled_blocks_paragraphs
   ```

2. **Accessing the API Endpoint:**
   Fetch blocks for a specific page by targeting the endpoint:
   ```
   /api/decoupled/_blocks?path=/your-path
   ```
   Example request:
   ```
   /api/decoupled/_blocks?path=/about-us
   ```

3. **Customizing Exposed Paragraph Data:**
   Implement the following hook to define which paragraph fields and relationships should be exposed:
   ```php
   /**
    * Alter the paragraph fields exposed by the Decoupled Blocks API.
    *
    * @param string $paragraphType
    *   The type of paragraph to filter.
    * @param array &$filters
    *   The array of filters to apply to the JSON:API response.
    */
   function hook_decoupled_blocks_filters_alter($paragraphType, &$filters) {
     switch ($paragraphType) {
       case "footer":
         $filters = [
           "fields" => [
             "block_content--template_block" => "block_machine_name",
             "media--image" => "name,thumbnail",
             "file--image" => "filename,uri",
           ],
           "include" => "field_logo,field_logo.thumbnail",
         ];
         break;
     }
   }
   ```

---

## **Additional Requirements**
- Drupal 10.x
- JSON:API module enabled

---

## **Recommended Modules/Libraries**
- [JSON:API Extras](https://www.drupal.org/project/jsonapi_extras) for enhanced customization of JSON:API responses.
